# -*- coding: utf-8 -*-
###########################################################################
# Eole NG - 2009
# Copyright Pole de Competence Eole  (Ministere Education - Academie Dijon)
# Licence CeCill  cf /root/LicenceEole.txt
# eole@ac-dijon.fr
###########################################################################
"""
    librairie de gestion des comptes 'Autres'
"""
from os.path import join
from ldap import MOD_REPLACE
from scribe.eoleuser import User, gen_common_attrs, send_first_mail
from scribe.eoletools import sshaDigest
from scribe.ldapconf import USER_DN, MAIL_DOMAIN, SPOOL_MAIL, AUTRE_FILTER


class Autre(User):
    """
        classe pour les autres utilistateurs
    """
    _type = 'autres'
    filtre = "(&%s)" % AUTRE_FILTER
    must_args = ['login', 'password', 'nom', 'prenom']
    may_args = dict(mail='local',
                    civilite='',
                    date='',
                    entlogin=True,
                    )
    has_samba = False
    has_ftp = False

    def _add_scribe_user(self, login, **args):
        """
            Création "Autre"
        """
        mail = args['mail']
        if mail == 'local':
            mail = "%s@%s" % (login, MAIL_DOMAIN['internet'])
            maildir = join(SPOOL_MAIL, login) + '/'
        else:
            maildir = ''

        # on crée d'abord l'objet 'inetOrgPerson'
        # puis on le met à jour ;)
        user_dn = USER_DN % dict(uid=login, _type=self._type)
        userpassword = sshaDigest(args['password'])
        datas = [(('objectClass', 'inetOrgPerson'))]
        datas.append(('uid', login))
        datas.append(('cn', "%(prenom)s %(nom)s" % args ))
        datas.append(('sn', args['nom']))
        datas.append(('userPassword', userpassword))
        datas.append(('displayName', "%(prenom)s %(nom)s" % args ))
        datas.append(('givenName', args['prenom'] ))
        self.ldap_admin._add(user_dn, datas)
        # le reste
        datas = []
        objectclass = self._get_attr(login, 'objectClass')
        objectclass.extend(['autre', 'ENTPerson'])
        datas.append((MOD_REPLACE, 'objectClass', objectclass))
        datas.extend(gen_common_attrs(login, **args))
        datas.append((MOD_REPLACE, 'sambaLMPassword', 'x' ))
        datas.append((MOD_REPLACE, 'sambaNTPassword', 'x' ))
        if mail != '':
            datas.append((MOD_REPLACE, 'mail', mail))
        if maildir != '':
            datas.append((MOD_REPLACE, 'mailHost', 'localhost'))
            datas.append((MOD_REPLACE, 'mailDir', maildir))
        self.ldap_admin._modify(user_dn, datas)
        if maildir != '':
            send_first_mail(mail)

    def _add_perso(self, login, **args):
        """
            pas de dossier
        """
        pass

    def _get_autres(self, attrs=['uid']):
        """
            Renvoie les user 'Autres'
        """
        return self._get_users(filtre=self.filtre, attrs=attrs)

    def _mod_mail(self, login, mailtype, mail=''):
        """
        modifie le compte mail d'un responsable
        login : login du responsable
        mailtype : perso ou local
        mail : adresse si mailtype == 'perso'
        """
        if mailtype == 'perso' and mail != '':
            self._set_mailperso(login, mail)
        else:
            self._set_localmail(login, domaine='internet')

