# -*- coding: utf-8 -*-
###########################################################################
# Eole NG - 2007
# Copyright Pole de Competence Eole  (Ministere Education - Academie Dijon)
# Licence CeCill  cf /root/LicenceEole.txt
# eole@ac-dijon.fr
###########################################################################

"""
 librairie pour le parsing des fichiers de données

 - parse_be1d_eleves : parsing des fichiers CSV issus de BE1D

"""
import sys
from csv import DictReader
from scribe.eoletools import replace_cars, convert_file, formate_date, \
clean_date
from scribe.importation import log
from scribe.importation.config import DEBUG_NUM
from scribe.storage import Eleve, Niveau, Classe


##########################################
# Extraction Be1d Elèves
# Fichier :
# - ecole.csv
##########################################
def parse_be1d_eleves(storage, csvfile):
    """
    parsing des élèves depuis Be1d
    """
    num = 0
    log.infolog("Lecture des élèves...", title=True)
    # fichier en UTF-8 ?
    convert_file(csvfile)
    # champs obligatoires
    fields = ['Nom Elève', 'Prénom Elève', 'Date naissance', 'Sexe',
            'Niveau','Classe']
    reader = DictReader(file(csvfile), delimiter=';')
    # validation en-tête
    #ATTENTION : ça commence direct par le 1er élève
    data = reader.next()
    for field in fields:
        if not data.has_key(field):
            log.errorlog("Le champ \"%s\" n'est pas présent dans l'en-tête du fichier !" % field)
            sys.exit(1)
    while True:
        eleve = {}
        eleve['prenom'] = unicode(replace_cars(data['Prénom Elève']))
        eleve['nom'] = unicode(replace_cars(data['Nom Elève']))
        eleve['date'] = unicode(formate_date(data['Date naissance']))
        #FIXME : trouver mieux comme numéro élève ?
        eleve['numero'] = unicode(clean_date(data['Date naissance']))
        # pas d'identifiant interne au logiciel
        eleve['int_id'] = u''
        if data['Sexe'] == 'F':
            eleve['civilite'] = u'3' #Mlle
        else:
            eleve['civilite'] = u'1' #M.
        try:
            my_eleve = Eleve(store=storage, **eleve)
            niveau = unicode(replace_cars(data['Niveau']))
            classe = unicode(replace_cars(data['Classe']))
            my_niveau = storage.findOrCreate(Niveau, nom=niveau)
            my_classe = storage.findOrCreate(Classe, nom=classe,
                                             niveau=my_niveau)
            # affectation de l'élève
            my_eleve.classe = my_classe
            my_eleve.niveau = my_niveau
            num += 1
            if num % DEBUG_NUM == 0:
                log.debuglog("%d élèves lus..." % num)
        except TypeError, msg:
            log.errorlog("Erreur sur l'élève %s : %s" % (data['Nom Elève'], msg))
        try:
            data = reader.next()
        except StopIteration:
            break
    log.infolog("TOTAL : %d élèves" % num)

